# vippool-storage

This project provides a library to access the vippool-clerk service, which is run by VIPPOOL Corp.,
and let you use Python to easily write to and read from the MonaCoin blockchain.

## Features

1. Consult the current balance of a coin-address for your private key.
2. Send coins to some other coin-address, from a coin-address for your private key.
3. Write arbitrary data to the blockchain. (requires a separate transaction fee)
4. Read arbitrary data from the blockchain.

## Installing

You can use pip to install the python package:
> $ pip install vippool_storage

## Usage

Please see the file [sample.py](sample.py) as an example.

## Contact

For asking for information, request features, or submit bug reports; please use the Github "issues" page.  
https://github.com/vippool/storage/issues

You can also send an email to our developers:  
dev-team@vippool.net

## License

(C) 2019-2019 VIPPOOL Inc.

This project is published under the MIT license.
